@@ -502,6 +502,9 @@ rb_ldap_conn_set_option (VALUE self, VALUE opt, VALUE data)
 #ifdef LDAP_OPT_X_TLS_REQUIRE_CERT
     case LDAP_OPT_X_TLS_REQUIRE_CERT:
 #endif
+#ifdef LDAP_OPT_X_TLS_NEWCTX
+    case LDAP_OPT_X_TLS_NEWCTX:
+#endif
 #endif
       idata = NUM2INT (data);
       optdata = &idata;
@@ -756,6 +759,7 @@ rb_ldap_conn_result2error (VALUE self, VALUE msg)
 
   GET_LDAP_DATA (self, ldapdata);
   Check_Kind (msg, rb_cLDAP_Entry);
+  Check_LDAPENTRY(msg);
   GET_LDAPENTRY_DATA (msg, edata);
 
   ldapdata->err = ldap_result2error (ldapdata->ldap, edata->msg, cdofree);
@@ -807,6 +811,7 @@ static VALUE
 rb_ldap_conn_invalidate_entry (VALUE msg)
 {
   RB_LDAPENTRY_DATA *edata;
+  Check_LDAPENTRY(msg);
   GET_LDAPENTRY_DATA (msg, edata);
   edata->ldap = NULL;
   edata->msg = NULL;
